#
# spec file for package lxqt-runner
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-runner
Version:        2.1.1
Release:        1.1
Summary:        LXQt application launcher
License:        LGPL-2.1-or-later
URL:            https://github.com/lxqt/lxqt-runner
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.18.0
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6WindowSystem)
BuildRequires:  cmake(LayerShellQt) >= 6.0.0
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  cmake(lxqt2-build-tools)
BuildRequires:  pkgconfig(libmenu-cache)
BuildRequires:  pkgconfig(lxqt) >= 2.1.0
BuildRequires:  pkgconfig(lxqt-globalkeys-ui)
BuildRequires:  pkgconfig(muparser)
Recommends:     %{name}-lang = %{version}-%{release}

%description
lxqt-runner provides a GUI that comes up on the desktop and allows for
launching applications or shutting down the system. A calculator function
is implemented too.

%lang_package

%prep
%autosetup

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}

%find_lang %{name} --with-qt

%check
%ctest

%files
%doc AUTHORS CHANGELOG README.md
%{_bindir}/%{name}
%{_mandir}/man?/%{name}.?%{?ext_man}
%config %{_sysconfdir}/xdg/autostart/%{name}.desktop
%license LICENSE

%files lang -f %{name}.lang
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%dir %{_datadir}/lxqt/translations/%{name}

%changelog
* Sat Jan 11 2025 Shawn Dunn <sfalken@opensuse.org>
- Update to version 2.1.1:
  * Suppressed new Qt warnings for invaled QRegularExpression
  * Fixed new crash on closing runner on Wayland
  * Updated manpages
- Specfile cleanup and added %%check section
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes (#290)
  * Updated *.ts files (#289)
  * Added scope=launcher (#288)
  * Weblate commits (#284)
  * Fixed multi-screen setups with Wayland (#286)
  * Added layershell runtime dependency (#283)
  * Update README.md (#281)
  * Weblate commits (#282)
  * Pre-release changes (#280)
  * Weblate commits (#279)
* Sat May 11 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6.
  * Full Wayland support is added to it by using layer shell.
* Mon Nov  6 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * An option is added for the top margin
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Updated VirtualBox icons for license compatibility.
  * Made the window frameless explicitly (for Wayland)
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Force the correct position on the window after it is moved
    from outside the app.
  * Added an option for clearing the entry on launching apps.
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Prevented redundant writings of dialog width to the config file.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Fixed compilation with menu-cache.
  * Visible names are used to sort items.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Prevent selection jumps in the drop-down list.
  * Copy the calculation result to clipboard.
  * Activated Home and End in the drop-down list.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Don't use QProcess deprecates methods.
  * Silenced the warnings about unused function parameters.
  * Drop the obsolete classs QDesktopWidget.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-runner.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Smoother and less CPU-intensive search.
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Fix build
- Add buildrequire for glib
* Thu Nov  7 2019 Michael Vetter <mvetter@suse.com>
- Remove old files:
  * lxqt-runner-0.14.0.tar.xz
  * lxqt-runner-0.14.0.tar.xz.asc
* Mon Feb 25 2019 mvetter@suse.com
- Update to 0.14.1:
  * MathItem: Use documented API of muparser and check for possible ArgSep()
    and DecSep() conflict. Also do not use grouping for output values.
  * Updated translations
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Installed former missed man page
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Remove BuildRequire for pkgconfig(libmenu-cache):
  Seems to create problems under some conditions.
  See https://forum.lxqt.org/t/release-lxqt-0-13-0/301
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * AppLinkItem: Make genericName searchable
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * Don't export github templates
  * Update CMakeLists.txt
  * Fixed typo in Lithuanian
  * Drops Qt5Core_VERSION_STRING
  * set Qt::AA_UseHighDpiPixmaps to true
  * Fix pedantic warning
  * ui: Add option to show particular count of items
  * runner: Make usage of history configurable
  * commanditemmodel: Remove unused methods
  * Added QCommandLineParser and basic cli interface to lxqt-runner
  * Added LXQT_RUNNER_PATCH_VERSION
  * Fixes a FTBFS in superbuild mode
  * Added merged autostart to CMakeLists.txt
  * Updated *_da.desktop files and removed *_da_DK.desktop files
  * Update desktop entries and Replace fr_FR by fr
  * Update Greek translation (el) Remove country variant from language code
  * CMake: Adds Runtime and Devel install COMPONENTs
  * Coding style changes
  * Updates the build system to use the Targets infrastructure
  * Drops hardcoded /etc/xdg paths
  * Updated german translation, replaced Qt4 by Qt in all xsession/translations
  * Updates translations infrastructure
  * Update the required minimum cmake version
  * remove dead template lines switch OnlyShowIn from Razor -> LXQt stringchanges LxQt -> LXQt
  * Support lxqt-session and add necessary xdg autostart desktop entry files.
  * Bump year
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * MathItem: Honor system locale (#52)
  * Use the new MenuCache configuration CMake module
  * Fixes FTBFS when libmenu-cache was installed to non-standard location
  * Remove cpack (#49)
  * - Fix endif placement when test for MATH library.
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Add README.md
  * Math: Enhance evaluation logic
  * Math: Use libmuparser for math evaluation
  * runner: Follow virtual desktop switching
  * Properly hide the runner when it loses focus
  * runner: Sort history items by relevance
  * build: Use external translations (#41)
  * ts-files removal (#40)
  * Use QString() instead of ""
  * Fix layout and focus to get history items right
  * Bump year
  * main: Add activation by running second instance
  * Italian translation update
  * dialog: Default icons
  * dialog: Fill background
  * upd: lxqt-runner_hu.ts
  * Update lxqt-runner_it.ts
- Add keyring
- Remove Qt5Script in favour of libmuparser as BuildRequire
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
* Mon Jan 26 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora builds
* Tue Nov 11 2014 andrea@opensuse.org
- Fixed license tag
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Wed May 14 2014 andrea@opensuse.org
- spec file cleanup for factory
* Tue May 13 2014 sfalken@opensuse.org
- Specfile Cleanup
* Mon May 12 2014 sfalken@opensuse.org
- removed fedora specfile, split into subproject
  Del: lxqt-runner-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Sat May 10 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-runner-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-runner-0.7.0.tar.xz
  Del:  _service
* Thu Apr  3 2014 sfalken@opensuse.org
- Intial Source Upload
  Add: _service
  Add: lxqt-runner.spec
  Add: lxqt-runner.changes
